import requests, json, random
from bs4 import BeautifulSoup
from bingsearchpy.useragent import useragent

class BingSearch:

    def __init__(self):
        self.data = []
        self.page = 0

    
    def request_data(self, url):

        try:
            # request data
            no = random.randint(0,len(useragent) - 1)
            page = 1
            req = requests.get(url, headers={"User-Agent": useragent[no]}).content

            # start scraping data
            soup = BeautifulSoup(req, 'html.parser')
            result_count = soup.find('span', class_ = 'sb_count').get_text().split(' ')[0].split(',')
            if len(result_count) > 0:
                container_count = ""
                for count in result_count:
                    container_count += str(count)
                # final_count = int(container_count)
                # self.page = final_count

            # parsing data ( title, link, description )
            final_data = []
            index = 0
            for data in soup.find_all(class_ = 'b_algo'):
                index += 1
                main = data.find('h2').find('a')
                list_data = {}
                list_data['no'] = index
                list_data['title']  = main.get_text()
                list_data['link']   = main.attrs['href']
                final_data.append(list_data)
            return final_data
        except:
            pass
        

    def search(self, query):
        """
        search data with random user agent
        """
        url = "https://www.bing.com/search?q=" + query + "&first="
        index = 1
        res = []
        for i in range(1,5):
            try:
                for data in self.request_data(url + str(i)):
                    res.append(data)
            except:
                pass
        return res

if __name__ != "__main__":
    engine = BingSearch()
else:
    pass


useragent = [
    "Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; en-en) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:48.0) Gecko/20100101 Firefox/48.0",
    "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36",
    "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36",
    "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/44.0.2403.157 Safari/537.36",
    "Mozilla/5.0 (Linux; U; Android 2.2) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 12_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148"
]


from distutils.core import setup
setup(
  name = 'bingsearchpy',
  packages = ['bingsearchpy'],
  version = '0.2',
  license='MIT',
  description = 'bing search engine for python',
  author = 'mrxxx04',
  author_email = 'rizkimaulana348@gmail.com',
  url = 'https://github.com/rizki4106/bingsearchpy',
  download_url = 'https://github.com/rizki4106/bingsearchpy/archive/v.0.1.zip',
  keywords = ['google','msn','searchengine', 'microsoft', 'google'],
  install_requires=[
          'requests',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)